import { ComponentType } from 'react';
import { CustomBlockRenderer } from 'react-native-render-html';
import { CustomTagRendererProps } from 'react-native-render-html';
import { HtmlAttributesDictionary } from 'react-native-render-html';
import { HTMLContentModel } from 'react-native-render-html';
import { HTMLElementModel } from '@native-html/transient-render-engine';
import { default as React_2 } from 'react';
import { RenderHTMLProps } from 'react-native-render-html';
import { StyleProp } from 'react-native';
import type { TBlock } from '@native-html/transient-render-engine';
import { ViewStyle } from 'react-native';

/**
 * A component to render iframes in react-native-render-html.
 *
 * @public
 */
export declare function HTMLIframe({ WebView, webViewProps: userWebViewProps, source, style, onLinkPress, scaleFactor, scalesPageToFit }: HTMLIframeProps): React_2.ReactElement<any, string | ((props: any) => React_2.ReactElement<any, string | any | (new (props: any) => React_2.Component<any, any, any>)> | null) | (new (props: any) => React_2.Component<any, any, any>)>;

/**
 * Props for the HTMLIframe component.
 *
 * @public
 */
export declare interface HTMLIframeProps<WebViewProps = any> extends IframeConfig {
    /**
     * The `WebView` Component you wish to use.
     */
    WebView: ComponentType<WebViewProps>;
    /**
     * Props to be passed to the `WebView` component;
     */
    webViewProps?: WebViewProps;
    /**
     * The source for the iframe.
     */
    source: {
        uri?: string;
        html?: string;
    };
    /**
     * Container style.
     */
    style: StyleProp<ViewStyle>;
    /**
     * Handle link press events.
     */
    onLinkPress?: RenderHTMLProps['onLinkPress'];
    /**
     * Html attributes for this iframe node.
     */
    htmlAttribs: HtmlAttributesDictionary;
    /**
     * When scalesPageToFit is enabled, scales the WebView zoom level to make sure the
     * viewport fits contentWidth.
     */
    scaleFactor: number;
}

/**
 * Configuration options for the HTMLIframe component.
 * You can pass those options through `renderersProps.iframe`
 * HTML prop.
 *
 * @public
 */
export declare interface IframeConfig {
    /**
     * When the iframe attribute width is wider than the contentWidth, scales
     * down the viewport so that it doesn't overflows horizontally.
     *
     * @remarks Although it looks like the eponymous `WebView` prop, it works
     * both on iOS and Android.
     *
     * @defaultvalue false
     */
    scalesPageToFit?: boolean;
    /**
     * Any props you'd like to pass to the `WebView` component.
     *
     * @remarks
     * `source` and `javascriptEnabled` will be ignored and overriden.
     */
    webViewProps?: any;
}

/**
 * The model to attach to custom iframe renderers.
 *
 * @public
 */
export declare const iframeModel: HTMLElementModel<'iframe', HTMLContentModel.block>;

/**
 * The renderer component for the iframe element. This renderer is fully
 * scalable, and will adjust to `contentWidth` and `computeEmbeddedMaxWidth`.
 * It also features `onLinkPress`.
 *
 * @public
 */
declare const IframeRenderer: CustomBlockRenderer;
export default IframeRenderer;

/**
 * Extract props for the HTMLIframe component from renderer function arguments.
 * This function is especially usefull for custom iframe renderers.
 *
 * @param props - The props of a custom block renderer.
 * @param iframeConfig - Override config options.
 *
 * @public
 */
export declare function useHtmlIframeProps({ key, style, tnode }: CustomTagRendererProps<TBlock>, iframeConfig?: IframeConfig): HTMLIframeProps | null;

export { }
